@@ -2,7 +2,6 @@ import hashlib
 from pathlib import Path
 from typing import Iterator
 
-from ..fs import link
 from ..utils import Some, unsome_
 from .destination import Destination
 from .manual_version import ManualVersion
@@ -17,15 +16,15 @@ class Links(ManualVersion, Destination):
         only: Some[str] = None,
         **kwargs,
     ) -> None:
+        super().__init__(**kwargs)
         self.source = Path(links).absolute()
         self.dot = dot
         self.shallow = shallow
         self.only = unsome_(only)
-        super().__init__(**kwargs)
 
     @property
     def name(self) -> str:
-        return f"links-{self.source}-{self.destination}"
+        return f"links-{self.source}-{self.destination_}-{self.dot}-{self.root}"
 
     def all_paths(self) -> Iterator[Path]:
         if not self.source.is_dir():
@@ -46,20 +45,21 @@ class Links(ManualVersion, Destination):
                 continue
             yield path
 
-    def get_remote_version(self) -> str:
+    async def get_remote_version(self) -> str:
         m = hashlib.sha256()
         for path in self.paths():
             m.update(str(path).encode())
         return m.hexdigest()
 
-    def install(self) -> None:
+    async def install(self) -> None:
         # TODO: remove links that were created before but no longer exist
+        destination = await self.destination()
         for path in self.paths():
             target = path.relative_to(self.source)
             if self.dot:
                 first_part, *parts = target.parts
                 target = Path("." + first_part, *parts)
-            target = self.destination.joinpath(target)
+            target = destination.joinpath(target)
 
-            link(path, target, sudo=self.root)
-        super().install()
+            await self.driver.link(path, target)
+        await super().install()
